summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/profile_sync_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/sync/profile_sync_factory.h')
-rw-r--r--chrome/browser/sync/profile_sync_factory.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/chrome/browser/sync/profile_sync_factory.h b/chrome/browser/sync/profile_sync_factory.h
index d956d3c..8e60f08 100644
--- a/chrome/browser/sync/profile_sync_factory.h
+++ b/chrome/browser/sync/profile_sync_factory.h
@@ -15,7 +15,6 @@
#include "chrome/browser/sync/glue/model_associator.h"
#include "chrome/browser/sync/unrecoverable_error_handler.h"
-class ExtensionSettingsBackend;
class PasswordStore;
class PersonalDataManager;
class ProfileSyncService;
@@ -115,10 +114,12 @@ class ProfileSyncFactory {
browser_sync::UnrecoverableErrorHandler* error_handler) = 0;
// Instantiates both a model associator and change processor for the
// extension setting data type. The pointers in the return struct are
// owned by the caller.
- virtual SyncComponents CreateExtensionSettingSyncComponents(
- ExtensionSettingsBackend* extension_settings_backend_,
+ virtual SyncComponents CreateExtensionOrAppSettingSyncComponents(
+ // Either EXTENSION_SETTINGS or APP_SETTINGS.
+ syncable::ModelType type,
+ SyncableService* settings_service,
ProfileSyncService* profile_sync_service,
browser_sync::UnrecoverableErrorHandler* error_handler) = 0;
@@ -115,10 +114,12 @@ class ProfileSyncFactory {
browser_sync::UnrecoverableErrorHandler* error_handler) = 0;
// Instantiates both a model associator and change processor for the
- // extension setting data type. The pointers in the return struct are
+ // extension or app setting data type. The pointers in the return struct are
// owned by the caller.